Class: Ittybit::Automations::AutomationsGetResponseWorkflowItem
- Inherits:
-
Object
- Object
- Ittybit::Automations::AutomationsGetResponseWorkflowItem
- Defined in:
- lib/ittybit/automations/types/automations_get_response_workflow_item.rb
Class Method Summary collapse
-
.from_json(json_object:) ⇒ Ittybit::Automations::AutomationsGetResponseWorkflowItem
Deserialize a JSON object to an instance of AutomationsGetResponseWorkflowItem.
-
.validate_raw(obj:) ⇒ Void
Leveraged for Union-type generation, validate_raw attempts to parse the given hash and check each fields type against the current object's property definitions.
Class Method Details
.from_json(json_object:) ⇒ Ittybit::Automations::AutomationsGetResponseWorkflowItem
Deserialize a JSON object to an instance of AutomationsGetResponseWorkflowItem
14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 |
# File 'lib/ittybit/automations/types/automations_get_response_workflow_item.rb', line 14 def self.from_json(json_object:) struct = JSON.parse(json_object, object_class: OpenStruct) begin Ittybit::Automations::AutomationsGetResponseWorkflowItemRef.validate_raw(obj: struct) unless struct.nil? return Ittybit::Automations::AutomationsGetResponseWorkflowItemRef.from_json(json_object: struct) end return nil rescue StandardError # noop end begin Ittybit::Automations::AutomationsGetResponseWorkflowItemConditions.validate_raw(obj: struct) unless struct.nil? return Ittybit::Automations::AutomationsGetResponseWorkflowItemConditions.from_json(json_object: struct) end return nil rescue StandardError # noop end struct end |
.validate_raw(obj:) ⇒ Void
Leveraged for Union-type generation, validate_raw attempts to parse the given hash and check each fields type against the current object's property definitions.
45 46 47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/ittybit/automations/types/automations_get_response_workflow_item.rb', line 45 def self.validate_raw(obj:) begin return Ittybit::Automations::AutomationsGetResponseWorkflowItemRef.validate_raw(obj: obj) rescue StandardError # noop end begin return Ittybit::Automations::AutomationsGetResponseWorkflowItemConditions.validate_raw(obj: obj) rescue StandardError # noop end raise("Passed value matched no type within the union, validation failed.") end |